==> bitcoin-0.21.1.knots20210629.tar.gz: bitcoin-0.21.1.knots20210629/src/qt/locale/bitcoin_zh-Hans.ts <==
<TS language="zh-Hans" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>创建一个新的地址</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>复制选定的地址到系统剪切板</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>从列表删除选定的地址</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>输入地址或者标签进行搜索</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>导出当前数据到文件</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>选择发送比特币地址</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>选择接收比特币地址</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>选择</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>发送地址</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>接收地址</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>这是你的比特币发币地址。发送前请确认发送数量和接收地址</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>复制标签</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>导出地址列表</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>逗号分隔文件(*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>导出失败</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>保存地址列表至%1时发生错误，请重试。</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>密码对话框</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>输入密码</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>新密码</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>重复输入新密码</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>显示密码</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>加密钱包</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>此操作需要您的钱包密码用来解锁钱包。</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>解锁钱包</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>此操作需要您的钱包密码用来解密钱包。</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation type="unfinished">&amp;加密钱包...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;发送地址</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;接收地址</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished"><numerusform /><numerusform /></translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>复制标签</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Encrypt Wallet</source>
        <translation>加密钱包</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;标签</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;地址</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    </context>
<context>
    <name>MempoolStats</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>地址</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">关闭</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation>复制地址</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;标签:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>复制标签</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">地址:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">标签:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">复制地址</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">选择...</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;标签:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>复制标签</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>逗号分隔文件(*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>导出失败</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>导出当前数据到文件</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>

==> bitcoin-21.2.knots20210629.tar.gz: bitcoin-21.2.knots20210629/src/qt/locale/bitcoin_zh-Hans.ts <==
<TS language="zh-Hans" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>创建一个新的地址</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>复制选定的地址到系统剪切板</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>从列表删除选定的地址</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>输入地址或者标签进行搜索</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>导出当前数据到文件</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>选择发送比特币地址</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>选择接收比特币地址</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>选择</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>发送地址</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>接收地址</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>这是你的比特币发币地址。发送前请确认发送数量和接收地址</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>复制标签</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>导出地址列表</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>逗号分隔文件(*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>导出失败</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>保存地址列表至%1时发生错误，请重试。</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>密码对话框</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>输入密码</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>新密码</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>重复输入新密码</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>显示密码</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>加密钱包</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>此操作需要您的钱包密码用来解锁钱包。</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>解锁钱包</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>此操作需要您的钱包密码用来解密钱包。</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>解密钱包</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>修改密码</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>确认钱包加密</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>注意:如果你加密了钱包又忘记了密码，你将会丢失所有的比特币！</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>你确定要将钱包加密吗？</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>钱包已加密</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>输入钱包的新密码。&lt;br/&gt;密码中请使用&lt;b&gt;10个或更多随机字符&lt;/b&gt;，或&lt;b&gt;8个或更多的单词&lt;/b&gt;。</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>输入钱包的旧密码和新密码。</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>需要加密的钱包</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>你的钱包将要被加密</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>你的钱包已被加密</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>钱包加密失败</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>钱包解锁失败</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation type="unfinished">&amp;加密钱包...</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;发送地址</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;接收地址</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>复制标签</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Encrypt Wallet</source>
        <translation>加密钱包</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;标签</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;地址</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>地址</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">关闭</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation>复制地址</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;标签:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>复制标签</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">地址:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">标签:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">复制地址</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">选择...</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;标签:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>复制标签</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>逗号分隔文件(*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>导出失败</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>导出当前数据到文件</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
